==> music_player-common-1.19.4-2.6.0.337-sources.jar: info/u_team/music_player/init/MusicPlayerResources.java <==
package info.u_team.music_player.init;

import info.u_team.music_player.MusicPlayerReference;
import net.minecraft.class_2960;

public class MusicPlayerResources {
	
	public static final class_2960 TEXTURE_CREATE = createResource("create");
	public static final class_2960 TEXTURE_OPEN = createResource("open");
	public static final class_2960 TEXTURE_CLEAR = createResource("clear");
	public static final class_2960 TEXTURE_PLAY = createResource("play");
	public static final class_2960 TEXTURE_STOP = createResource("stop");
	public static final class_2960 TEXTURE_PAUSE = createResource("pause");
	public static final class_2960 TEXTURE_ADD = createResource("add");
	public static final class_2960 TEXTURE_UP = createResource("up");
	public static final class_2960 TEXTURE_DOWN = createResource("down");
	public static final class_2960 TEXTURE_BACK = createResource("back");
	public static final class_2960 TEXTURE_SKIP_FORWARD = createResource("skip-forward");
	public static final class_2960 TEXTURE_SKIP_BACK = createResource("skip-back");
	public static final class_2960 TEXTURE_SHUFFLE = createResource("shuffle");
	public static final class_2960 TEXTURE_REPEAT = createResource("repeat");
	public static final class_2960 TEXTURE_REPEAT_SINGLE = createResource("repeat-single");
	public static final class_2960 TEXTURE_SETTINGS = createResource("settings");
	
	public static final class_2960 TEXTURE_SOCIAL_YOUTUBE = createResource("socialmedia/youtube-logo");
	public static final class_2960 TEXTURE_SOCIAL_SOUNDCLOUD = createResource("socialmedia/soundcloud-logo");
	
	private static class_2960 createResource(String name) {
		return new class_2960(MusicPlayerReference.MODID, "textures/gui/" + name + ".png");
	}
	
}

==> music_player-common-1.21.1-2.7.1.329-sources.jar: info/u_team/music_player/init/MusicPlayerResources.java <==
package info.u_team.music_player.init;

import info.u_team.music_player.MusicPlayerReference;
import net.minecraft.class_2960;

public class MusicPlayerResources {
	
	public static final class_2960 TEXTURE_CREATE = createResource("create");
	public static final class_2960 TEXTURE_OPEN = createResource("open");
	public static final class_2960 TEXTURE_CLEAR = createResource("clear");
	public static final class_2960 TEXTURE_PLAY = createResource("play");
	public static final class_2960 TEXTURE_STOP = createResource("stop");
	public static final class_2960 TEXTURE_PAUSE = createResource("pause");
	public static final class_2960 TEXTURE_ADD = createResource("add");
	public static final class_2960 TEXTURE_UP = createResource("up");
	public static final class_2960 TEXTURE_DOWN = createResource("down");
	public static final class_2960 TEXTURE_BACK = createResource("back");
	public static final class_2960 TEXTURE_SKIP_FORWARD = createResource("skip-forward");
	public static final class_2960 TEXTURE_SKIP_BACK = createResource("skip-back");
	public static final class_2960 TEXTURE_SHUFFLE = createResource("shuffle");
	public static final class_2960 TEXTURE_REPEAT = createResource("repeat");
	public static final class_2960 TEXTURE_REPEAT_SINGLE = createResource("repeat-single");
	public static final class_2960 TEXTURE_SETTINGS = createResource("settings");
	
	public static final class_2960 TEXTURE_SOCIAL_YOUTUBE = createResource("socialmedia/youtube-logo");
	public static final class_2960 TEXTURE_SOCIAL_SOUNDCLOUD = createResource("socialmedia/soundcloud-logo");
	
	private static class_2960 createResource(String name) {
		return class_2960.method_60655(MusicPlayerReference.MODID, "textures/gui/" + name + ".png");
	}
	
}
